pub enum SqlEnumError {
UnknownLabel {
enum_name: &'static str,
value: String,
},
UnknownCode {
enum_name: &'static str,
value: i64,
},
}Expand description
Error returned when a database value does not match a generated SQL enum.
Variants
UnknownLabel
A text-backed enum label was not one of the known variants.
Fields
UnknownCode
An integer-backed enum code was not one of the known variants.