pub struct SchemaBuilder { /* private fields */ }Implementations
Sourceimpl SchemaBuilder
impl SchemaBuilder
pub fn new(dialect: Dialect) -> SchemaBuilder
Sourcepub fn table<T>(self) -> SchemaBuilderwhere
T: IntoTable,
pub fn table<T>(self) -> SchemaBuilderwhere
T: IntoTable,
Add a table from any type that implements IntoTable.
Sourcepub fn table_def(self, table: Table) -> SchemaBuilder
pub fn table_def(self, table: Table) -> SchemaBuilder
Add a fully constructed modeled table definition.
pub fn extension(self, name: impl Into<String>) -> SchemaBuilder
pub fn extension_versioned( self, name: impl Into<String>, version: impl Into<String>, ) -> SchemaBuilder
Sourcepub fn extension_def(self, extension: ExtensionDef) -> SchemaBuilder
pub fn extension_def(self, extension: ExtensionDef) -> SchemaBuilder
Add a fully constructed extension definition.
pub fn view( self, name: impl Into<String>, definition: impl Into<String>, ) -> SchemaBuilder
Sourcepub fn view_def(self, view: ViewDef) -> SchemaBuilder
pub fn view_def(self, view: ViewDef) -> SchemaBuilder
Add a fully constructed view definition.
pub fn function(self, f: FunctionDef) -> SchemaBuilder
pub fn enum_type( self, name: impl Into<String>, values: &[&str], ) -> SchemaBuilder
Sourcepub fn enum_def(self, enum_def: EnumDef) -> SchemaBuilder
pub fn enum_def(self, enum_def: EnumDef) -> SchemaBuilder
Add a fully constructed enum definition.
Sourcepub fn build(self) -> Result<Schema, SchemaLoadError>
pub fn build(self) -> Result<Schema, SchemaLoadError>
Build a schema through the same normalize and prepare lifecycle as file and SQL ingestion.